# Curl_Navi
> Class and functions of curriculum reinforcement learning for robot navigation


## 0. Setup

We setup a docker container for running the code.

### 0.1 Docker

host $ source ipc_run.sh

### 0.2 Generate README and Documentations

docker $ nbdev_build_docs

### 0.3 Generate Python Library

docker $ nbdev_build_lib

## 1. Get Started

### 1.1 Download Environments 

### 1.2 Visualize Paires of Start and End Points

### 1.3 Visualize Environment Difficulty

## 2. Inference

### 2.1 Download Pre-trained Weights

### 2.2 Run Single Inference

### 2.3 Run Evaluations

`cd ~/curl_navi`

## 3. Training 

### 3.1 Training in Single Environment

### 3.2 Curriculum RL Training in 2 Environmets 

### 3.3 Curriculum Scheduler
